@@ -7,15 +7,15 @@ use bevy_prototype_lyon::shapes::RectangleOrigin;
 
 use heron_core::CollisionShape;
 use heron_rapier::convert::IntoBevy;
-use heron_rapier::rapier::geometry::{ColliderHandle, ColliderSet, Shape};
+use heron_rapier::rapier2d::geometry::{ColliderHandle, ColliderSet, Shape};
 
 use super::*;
 
 pub(crate) fn systems() -> SystemSet {
     SystemSet::new()
-        .with_system(dim2::delete_debug_sprite.system())
-        .with_system(dim2::replace_debug_sprite.system())
-        .with_system(dim2::create_debug_sprites.system())
+        .with_system(delete_debug_sprite.system())
+        .with_system(replace_debug_sprite.system())
+        .with_system(create_debug_sprites.system())
 }
 
 fn create_debug_sprites(
